@@ -55,6 +55,7 @@ struct _EogThumbViewPrivate {
 	gint start_thumb; /* the first visible thumbnail */
 	gint end_thumb;   /* the last visible thumbnail  */
 	GtkWidget *menu;  /* a contextual menu for thumbnails */
+	GtkCellRenderer *pixbuf_cell;
 };
 
 /* Drag 'n Drop */
@@ -459,17 +460,34 @@ tb_on_query_tooltip_cb (GtkWidget  *widget,
 static void
 eog_thumb_view_init (EogThumbView *tb)
 {
+	tb->priv = EOG_THUMB_VIEW_GET_PRIVATE (tb);
+	
+	tb->priv->pixbuf_cell = gtk_cell_renderer_pixbuf_new ();
+
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (tb), 
+	      	  		    tb->priv->pixbuf_cell, 
+	      			    FALSE);
+	
+	g_object_set (tb->priv->pixbuf_cell, 
+	              "follow-state", TRUE, 
+	              "height", 100, 
+	              "yalign", 0.5, 
+	              "xalign", 0.5, 
+	              NULL);
+	
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (tb),
+	                                tb->priv->pixbuf_cell, 
+	      		                "pixbuf", EOG_LIST_STORE_THUMBNAIL,
+	                                NULL);
+
 	gtk_icon_view_set_selection_mode (GTK_ICON_VIEW (tb),
  					  GTK_SELECTION_MULTIPLE);
-
-	gtk_icon_view_set_pixbuf_column (GTK_ICON_VIEW (tb),
-					 EOG_LIST_STORE_THUMBNAIL);
 	
 	gtk_icon_view_set_column_spacing (GTK_ICON_VIEW (tb),
 					  EOG_THUMB_VIEW_SPACING);
 
 	gtk_icon_view_set_row_spacing (GTK_ICON_VIEW (tb),
-					  EOG_THUMB_VIEW_SPACING);
+				       EOG_THUMB_VIEW_SPACING);
 
 #ifdef HAVE_GTK_TOOLTIP
 	g_object_set (tb, "has-tooltip", TRUE, NULL);
@@ -480,8 +498,6 @@ eog_thumb_view_init (EogThumbView *tb)
 			  NULL);
 #endif /* HAVE_GTK_TOOLTIP */	
 	
-	tb->priv = EOG_THUMB_VIEW_GET_PRIVATE (tb);
-	
 	tb->priv->start_thumb = 0;
 	tb->priv->end_thumb = 0;
 	tb->priv->menu = NULL;
@@ -525,6 +541,16 @@ eog_thumb_view_set_model (EogThumbView *tb, EogListStore *store)
 	}
 }
 
+void
+eog_thumb_view_set_item_height (EogThumbView *tb, gint height)
+{
+	g_return_if_fail (EOG_IS_THUMB_VIEW (tb));
+
+	g_object_set (tb->priv->pixbuf_cell, 
+	              "height", height, 
+	              NULL);
+}
+
 static void
 eog_thumb_view_get_n_selected_helper (GtkIconView *tb,
 				      GtkTreePath *path,
